==> snappydata-store-core-1.5.1-sources.jar: com/pivotal/gemfirexd/internal/iapi/jdbc/EngineStatement.java <==
/*

   Derby - Class com.pivotal.gemfirexd.internal.iapi.jdbc.EngineStatement

   Licensed to the Apache Software Foundation (ASF) under one or more
   contributor license agreements.  See the NOTICE file distributed with
   this work for additional information regarding copyright ownership.
   The ASF licenses this file to you under the Apache License, Version 2.0
   (the "License"); you may not use this file except in compliance with
   the License.  You may obtain a copy of the License at

      http://www.apache.org/licenses/LICENSE-2.0

   Unless required by applicable law or agreed to in writing, software
   distributed under the License is distributed on an "AS IS" BASIS,
   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
   See the License for the specific language governing permissions and
   limitations under the License.

 */
package com.pivotal.gemfirexd.internal.iapi.jdbc;

import java.sql.SQLException;
import java.sql.Statement;


/**
 * Additional methods the embedded engine exposes on its Statement object
 * implementations. An internal api only, mainly for the network
 * server. Allows consistent interaction between emebdded statements
 * and brokered statements.
 * 
 */
public interface EngineStatement extends Statement {
    
    /**
     * Identical to the JDBC 3 getMoreResults(int).
     * 
     * @see java.sql.Statement#getMoreResults(int)
     */
    public boolean getMoreResults(int current) throws SQLException;
    
    /**
     * Identical to the JDBC 3 getResultSetHoldability(int).
     * 
     * @see java.sql.Statement#getResultSetHoldability()
     */ 
    public int getResultSetHoldability() throws SQLException;
}

==> snappydata-store-core-1.5.6-rc1-sources.jar: com/pivotal/gemfirexd/internal/iapi/jdbc/EngineStatement.java <==
/*

   Derby - Class com.pivotal.gemfirexd.internal.iapi.jdbc.EngineStatement

   Licensed to the Apache Software Foundation (ASF) under one or more
   contributor license agreements.  See the NOTICE file distributed with
   this work for additional information regarding copyright ownership.
   The ASF licenses this file to you under the Apache License, Version 2.0
   (the "License"); you may not use this file except in compliance with
   the License.  You may obtain a copy of the License at

      http://www.apache.org/licenses/LICENSE-2.0

   Unless required by applicable law or agreed to in writing, software
   distributed under the License is distributed on an "AS IS" BASIS,
   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
   See the License for the specific language governing permissions and
   limitations under the License.

 */
package com.pivotal.gemfirexd.internal.iapi.jdbc;

import java.sql.SQLException;
import java.sql.Statement;


/**
 * Additional methods the embedded engine exposes on its Statement object
 * implementations. An internal api only, mainly for the network
 * server. Allows consistent interaction between emebdded statements
 * and brokered statements.
 * 
 */
public interface EngineStatement extends Statement {
    
    /**
     * Identical to the JDBC 3 getMoreResults(int).
     * 
     * @see java.sql.Statement#getMoreResults(int)
     */
    public boolean getMoreResults(int current) throws SQLException;
    
    /**
     * Identical to the JDBC 3 getResultSetHoldability(int).
     * 
     * @see java.sql.Statement#getResultSetHoldability()
     */ 
    public int getResultSetHoldability() throws SQLException;

    /** Returns true if this is a {@link java.sql.PreparedStatement}. */
    public boolean isPrepared() throws SQLException;

    /** Returns true if there are dynamic ResultSet from a procedure call. */
    public boolean hasDynamicResults() throws SQLException;

    /** Try and clear the batch even if statement is marked as closed. */
    public void forceClearBatch();

    /** Reset the connection so that it can be reused. */
    public void resetForReuse() throws SQLException;

    /**
     * Change the type, concurrency and holdability of this statement.
     */
    public void reset(int newType, int newConcurrency, int newHoldability)
        throws SQLException;

    public void clearFinalizer();
}
